#[repr(u8)]pub enum JsonOutput {
Single(String),
Multiple(Vec<String>),
}Expand description
Output type for JSON flattening operations
Variants
Implementations
Sourceimpl JsonOutput
impl JsonOutput
Sourcepub fn into_single(self) -> String
👎Deprecated since 0.10.0: Use try_into_single() instead to avoid panics
pub fn into_single(self) -> String
Use try_into_single() instead to avoid panics
Extract single result, panicking if multiple results.
Panics
Panics if this is a Multiple variant. Use try_into_single
for a non-panicking alternative.
Sourcepub fn into_multiple(self) -> Vec<String>
👎Deprecated since 0.10.0: Use try_into_multiple() instead to avoid panics
pub fn into_multiple(self) -> Vec<String>
Use try_into_multiple() instead to avoid panics
Extract multiple results, panicking if single result.
Panics
Panics if this is a Single variant. Use try_into_multiple
for a non-panicking alternative.
Sourcepub fn try_into_single(self) -> Result<String, JsonToolsError>
pub fn try_into_single(self) -> Result<String, JsonToolsError>
Try to extract single result, returning an error if multiple results.
Sourcepub fn try_into_multiple(self) -> Result<Vec<String>, JsonToolsError>
pub fn try_into_multiple(self) -> Result<Vec<String>, JsonToolsError>
Try to extract multiple results, returning an error if single result.