#[non_exhaustive]pub struct BooleanConversionConfig {
pub enabled: bool,
pub extra_true_tokens: SmallVec<[String; 2]>,
pub extra_false_tokens: SmallVec<[String; 2]>,
}Expand description
Configuration for boolean-string detection, used by TypeConversionConfig.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.enabled: boolEnable boolean-string detection and conversion
extra_true_tokens: SmallVec<[String; 2]>Additional strings recognized as true, beyond the built-in list ("true",
"TRUE", "True", "yes", "YES", "Yes", "y", "Y", "on", "ON",
"On"). Additive only. Matched exactly (case-sensitive).
extra_false_tokens: SmallVec<[String; 2]>Additional strings recognized as false, beyond the built-in list ("false",
"FALSE", "False", "no", "NO", "No", "n", "N", "off", "OFF",
"Off"). Additive only. Matched exactly (case-sensitive).
Implementations
Sourceimpl BooleanConversionConfig
impl BooleanConversionConfig
Sourcepub fn add_extra_true_token(self, token: impl Into<String>) -> Self
pub fn add_extra_true_token(self, token: impl Into<String>) -> Self
Add an additional string to recognize as true, beyond the built-in list
Sourcepub fn add_extra_false_token(self, token: impl Into<String>) -> Self
pub fn add_extra_false_token(self, token: impl Into<String>) -> Self
Add an additional string to recognize as false, beyond the built-in list
Sourcepub fn has_extra_tokens(&self) -> bool
pub fn has_extra_tokens(&self) -> bool
Check if any extra boolean tokens are configured